@@ -255,7 +255,7 @@ class SortedSlices:
         # TODO: fix bad init -> bad result
         if not values:
             return tuple()
-        approx_unique: typing.Dict[T, builtins.int] = dict()
+        approx_unique: builtins.dict[T, builtins.int] = dict()
         for val in values:
             min_dist = np.inf
             min_dist_val = None
@@ -352,7 +352,7 @@ class DICOMDir:
         elif (
             not isinstance(dicom_path, (builtins.str, pathlib.Path))
             and miou.is_iterable(dicom_path)
-            and all(str(p).endswith(f".{extension}") for p in dicom_path)  # type: ignore[union-attr]  # noqa: E501
+            and all(str(p).endswith(extension) for p in dicom_path)  # type: ignore[union-attr]  # noqa: E501
         ):
             paths = tuple(dicom_path)  # type: ignore[arg-type]
         else:
